summaryrefslogtreecommitdiff
path: root/basic/source/app/appwin.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'basic/source/app/appwin.hxx')
-rw-r--r--basic/source/app/appwin.hxx54
1 files changed, 27 insertions, 27 deletions
diff --git a/basic/source/app/appwin.hxx b/basic/source/app/appwin.hxx
index 0e864e69eef9..928380d50df8 100644
--- a/basic/source/app/appwin.hxx
+++ b/basic/source/app/appwin.hxx
@@ -35,15 +35,15 @@
#include "app.hxx"
#include "dataedit.hxx"
-typedef USHORT QueryBits;
+typedef sal_uInt16 QueryBits;
#define QUERY_NONE ( QueryBits ( 0x00 ) )
#define QUERY_DIRTY ( QueryBits ( 0x01 ) )
#define QUERY_DISK_CHANGED ( QueryBits ( 0x02 ) )
#define QUERY_ALL ( QUERY_DIRTY | QUERY_DISK_CHANGED )
#define SAVE_NOT_DIRTY ( QueryBits ( 0x04 ) )
-#define SAVE_RES_SAVED TRUE
-#define SAVE_RES_NOT_SAVED FALSE
+#define SAVE_RES_SAVED sal_True
+#define SAVE_RES_NOT_SAVED sal_False
#define SAVE_RES_ERROR 3
#define SAVE_RES_CANCEL 4
@@ -69,68 +69,68 @@ protected:
static short nCount; // number of edit windows
static String *pNoName; // "Untitled"
FileStat aLastAccess; // Last access time of loaded file
- USHORT nSkipReload; // Sometimes there must not be a reload
- BOOL bHasFile; // Otherwise reload does not make sense
- BOOL bReloadAborted; // Is set if reload was cancelled so that we can ask again wehn closing
+ sal_uInt16 nSkipReload; // Sometimes there must not be a reload
+ sal_Bool bHasFile; // Otherwise reload does not make sense
+ sal_Bool bReloadAborted; // Is set if reload was cancelled so that we can ask again wehn closing
short nId; // ID-Nummer( "Unnamed n" )
BasicFrame* pFrame; // Parent-Window
// Icon* pIcon; // Document icon
String aFind; // Search string
String aReplace; // Replace string
- BOOL bFind; // TRUE if search not replace
+ sal_Bool bFind; // sal_True if search not replace
void RequestHelp( const HelpEvent& ); // Help handler
void GetFocus(); // activate
- virtual USHORT ImplSave(); // Save file
- USHORT nWinState; // Maximized, Iconized or Normal
+ virtual sal_uInt16 ImplSave(); // Save file
+ sal_uInt16 nWinState; // Maximized, Iconized or Normal
Point nNormalPos; // Position if normal
Size nNormalSize; // Size if Normal
virtual long PreNotify( NotifyEvent& rNEvt );
- USHORT nWinId;
+ sal_uInt16 nWinId;
public:
TYPEINFO();
AppWin( BasicFrame* );
~AppWin();
DataEdit* pDataEdit; // Data area
- virtual USHORT GetLineNr()=0; // Current line number
+ virtual sal_uInt16 GetLineNr()=0; // Current line number
virtual long InitMenu( Menu* ); // Init of the menu
virtual long DeInitMenu( Menu* ); // reset to enable all shortcuts
virtual void Command( const CommandEvent& rCEvt ); // Command handler
virtual void Resize();
virtual void Help();
- virtual BOOL Load( const String& ); // Load file
+ virtual sal_Bool Load( const String& ); // Load file
virtual void PostLoad(){} // Set source at module
- virtual USHORT SaveAs(); // Save file as
+ virtual sal_uInt16 SaveAs(); // Save file as
virtual void PostSaveAs(){}
virtual void Find(); // find text
virtual void Replace(); // replace text
virtual void Repeat(); // repeat find/replace
- virtual BOOL Close(); // close window
+ virtual sal_Bool Close(); // close window
virtual void Activate(); // window was activated
virtual FileType GetFileType()=0; // returns the filetype
- virtual BOOL ReloadAllowed(){ return TRUE; }
+ virtual sal_Bool ReloadAllowed(){ return sal_True; }
virtual void Reload(); // Reload after change on disk
virtual void LoadIniFile(){;} // (re)load ini file after change
void CheckReload(); // Checks and asks if reload should performed
- BOOL DiskFileChanged( USHORT nWhat ); // Checks file for changes
- void UpdateFileInfo( USHORT nWhat ); // Remembers last file state
- BOOL IsSkipReload(); // Should we test reload?
- void SkipReload( BOOL bSkip = TRUE );
- USHORT GetWinState(){ return nWinState; }
+ sal_Bool DiskFileChanged( sal_uInt16 nWhat ); // Checks file for changes
+ void UpdateFileInfo( sal_uInt16 nWhat ); // Remembers last file state
+ sal_Bool IsSkipReload(); // Should we test reload?
+ void SkipReload( sal_Bool bSkip = sal_True );
+ sal_uInt16 GetWinState(){ return nWinState; }
void Maximize();
void Restore();
- void Minimize( BOOL bMinimize );
- void Cascade( USHORT nNr );
+ void Minimize( sal_Bool bMinimize );
+ void Cascade( sal_uInt16 nNr );
- USHORT QuerySave( QueryBits nBits = QUERY_ALL );
- BOOL IsModified() { return pDataEdit->IsModified(); }
+ sal_uInt16 QuerySave( QueryBits nBits = QUERY_ALL );
+ sal_Bool IsModified() { return pDataEdit->IsModified(); }
BasicFrame* GetBasicFrame() { return pFrame; }
- virtual void TitleButtonClick( USHORT nButton );
+ virtual void TitleButtonClick( sal_uInt16 nButton );
virtual void SetText( const XubString& rStr );
- USHORT GetWinId() { return nWinId; }
- void SetWinId( USHORT nWId ) { nWinId = nWId; }
+ sal_uInt16 GetWinId() { return nWinId; }
+ void SetWinId( sal_uInt16 nWId ) { nWinId = nWId; }
};
DECLARE_LIST( EditList, AppWin* )